==> haskell-xmlgen-0.6.2.2-184-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xmlgen.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xmlgen
version:              0.6.2.2
visibility:           public
id:                   xmlgen-0.6.2.2-KNK5ZJVhLMmHMD7iync5cb
key:                  xmlgen-0.6.2.2-KNK5ZJVhLMmHMD7iync5cb
license:              BSD-3-Clause
maintainer:           Stefan Wehr <wehr@factisresearch.com>
author:
    Stefan Wehr, Stefan Schmidt, Johannes Weiss, David Leuschner

synopsis:             Fast XML generation library
description:          Library for high-performance XML generation.
category:             Text, XML
abi:                  daaf06c7294fa7ba565de7fd08248833
exposed:              True
exposed-modules:      Text.XML.Generator
import-dirs:          /usr/lib/ghc-9.6.6/site-local/xmlgen-0.6.2.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/xmlgen-0.6.2.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/xmlgen-0.6.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xmlgen
hs-libraries:         HSxmlgen-0.6.2.2-KNK5ZJVhLMmHMD7iync5cb
depends:
    base-4.18.2.1 blaze-builder-0.4.4.1-3wnAa360A0589gqzb0DfpQ
    bytestring-0.11.5.3 containers-0.6.7 mtl-2.3.1 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-xmlgen/html/xmlgen.haddock
haddock-html:         /usr/share/doc/haskell-xmlgen/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xmlgen-0.6.2.2-185-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xmlgen.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xmlgen
version:              0.6.2.2
visibility:           public
id:                   xmlgen-0.6.2.2-3maclIX8N2BA9kXWbKgd9l
key:                  xmlgen-0.6.2.2-3maclIX8N2BA9kXWbKgd9l
license:              BSD-3-Clause
maintainer:           Stefan Wehr <wehr@factisresearch.com>
author:
    Stefan Wehr, Stefan Schmidt, Johannes Weiss, David Leuschner

synopsis:             Fast XML generation library
description:          Library for high-performance XML generation.
category:             Text, XML
abi:                  cb42936b3a778a100652e28e2843a9fa
exposed:              True
exposed-modules:      Text.XML.Generator
import-dirs:          /usr/lib/ghc-9.6.6/site-local/xmlgen-0.6.2.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/xmlgen-0.6.2.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/xmlgen-0.6.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xmlgen
hs-libraries:         HSxmlgen-0.6.2.2-3maclIX8N2BA9kXWbKgd9l
depends:
    base-4.18.2.1 blaze-builder-0.4.4.1-2e1Y8rZXOgP89l4uRglwJl
    bytestring-0.11.5.3 containers-0.6.7 mtl-2.3.1 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-xmlgen/html/xmlgen.haddock
haddock-html:         /usr/share/doc/haskell-xmlgen/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
